==> s-datepicker-1.0.2.tgz: package/src/components/DatePicker.tsx <==
// DatePicker.tsx
import React, { useEffect, useState } from 'react';
import sdate from '@saanaa.com/s-date';
import Header from './Header';
import { getMonthDetails, getSubTitles, createArray } from '../utils';
import { DatePickerProps, DayItem, MonthItem, Locale } from '../types';

const DatePicker: React.FC<DatePickerProps> = ({
  onChange,
  title = 'تاریخ انتخابی',
  numberOfMonth = 1,
  subTitles = [],
  isDisabledPast = true,
  submitBtnAction = () => {}
}) => {
  const [localeState, setLocaleState] = useState<Locale>('fa');
  const [localeTitle, setLocaleTitle] = useState('تقویم میلادی');
  const [selectedDate, setSelectedDate] = useState<DayItem | undefined>();
  const [monthsState, setMonthsState] = useState<MonthItem[]>([]);

  const todayGregorian = sdate.format('en', new Date(), '/').YYYY_MM_dd;
  let currentYear = sdate.convert('fa', new Date()).YYYY as any;
  let currentMonth = sdate.convert('fa', new Date()).MM;

  useEffect(() => {
    setMonthsState(
      getMonthDetails('fa', currentYear, currentMonth, numberOfMonth, subTitles, todayGregorian)
    );
  }, [numberOfMonth, subTitles, todayGregorian, currentYear, currentMonth]);

  const toggleCalendarType = () => {
    const newLocale = localeState === 'en' ? 'fa' : 'en';
    setLocaleState(newLocale);
    setLocaleTitle(newLocale === 'en' ? 'تقویم شمسی' : 'تقویم میلادی');
    currentYear = sdate.format(newLocale, new Date()).YYYY;
    currentMonth = sdate.format(newLocale, new Date()).MM;
    setMonthsState(
      getMonthDetails(
        newLocale,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const nextMonth = () => {
    if (+currentMonth + 1 === 13) {
      currentYear++;
      currentMonth = 1;
    } else {
      currentMonth++;
    }
    setMonthsState(
      getMonthDetails(
        localeState,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const prevMonth = () => {
    if (
      isDisabledPast &&
      +currentMonth === +sdate.convert(localeState, new Date()).MM &&
      +currentYear === +sdate.convert(localeState, new Date()).YYYY
    )
      return;

    if (+currentMonth - 1 === 0) {
      currentYear--;
      currentMonth = 12;
    } else {
      currentMonth--;
    }
    setMonthsState(
      getMonthDetails(
        localeState,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const gotoToday = () => {
    setMonthsState(
      getMonthDetails(
        localeState,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const handleChange = (date: DayItem) => {
    setSelectedDate(date);
    onChange(date.jalaliDate);
  };

  return (
    <div
      className={`calendar ${numberOfMonth > 1 ? 'active' : ''} ${localeState === 'fa' ? '-rtl' : '-ltr'}`}
    >
      <div className="calendar__navigation fixed-position">
        <button type="button" onClick={gotoToday}>
          برو به امروز
        </button>
        <button type="button" onClick={toggleCalendarType}>
          {localeTitle}
        </button>
      </div>

      <div className="s-relative s-w-full s-block">
        <Header onNextMonth={nextMonth} onPrevMonth={prevMonth} />

        <div className="s-p-3 s-grid md:s-flex s-gap-8">
          {monthsState.map((monthItem, monthIndex) => (
            <div key={monthIndex} className="s-flex-1 s-mt-[2px]">
              <div className="s-grid s-grid-cols-5 s-items-center s-gap-x-3 s-mx-1.5 s-pb-2 s-pt-4">
                <span className="s-text-left s-text-black s-font-semibold s-text-base md:s-text-sm s-col-span-5 s-mb-2">
                  {`${monthItem.monthName} ${monthItem.year}`}
                </span>

                {['ش', 'ی', 'د', 'س', 'چ', 'پ', 'ج'].map((weekDay, weekIndex) => (
                  <span
                    key={weekIndex}
                    className="s-text-center s-text-slate-600 s-font-semibold s-text-sm"
                  >
                    {weekDay}
                  </span>
                ))}

                {monthItem.days.map((dayItem, dayIndex) => (
                  <div key={dayIndex} className="s-relative s-mt-2">
                    <button
                      type="button"
                      onClick={() => handleChange(dayItem)}
                      className={`${
                        selectedDate && selectedDate.value === dayItem.value ? 'selected' : ''
                      } ${dayItem.isPassed ? 's-text-gray-400' : 's-text-gray-700'} s-w-12 s-h-12 s-flex s-items-center s-justify-center s-bg-transparent`}
                      disabled={dayItem.isPassed}
                    >
                      {dayItem.day}
                    </button>
                    {dayItem.subTitle && (
                      <span className="s-absolute s-top-0 s-right-0 s-bg-red-500 s-text-white s-rounded-full s-w-4 s-h-4 s-flex s-items-center s-justify-center s-text-xs">
                        {dayItem.subTitle}
                      </span>
                    )}
                  </div>
                ))}
              </div>
            </div>
          ))}
        </div>

        <div className="s-relative s-w-full s-mt-8 s-pb-4">
          <button type="button" className="s-btn s-btn-primary s-w-full" onClick={submitBtnAction}>
            ثبت تاریخ
          </button>
        </div>
      </div>
    </div>
  );
};

export default DatePicker;

==> s-datepicker-1.0.3.tgz: package/src/components/DatePicker.tsx <==
// DatePicker.tsx
import React, { useEffect, useState } from 'react';
import sdate from '@saanaa.com/s-date';
import Header from './Header';
import { getMonthDetails } from '../utils';
import { DatePickerProps, DayItem, MonthItem, Locale } from '../types';

const DatePicker: React.FC<DatePickerProps> = ({
  onChange,
  // title = 'تاریخ انتخابی',
  numberOfMonth = 1,
  subTitles = [],
  isDisabledPast = true,
  submitBtnAction = () => {}
}) => {
  const [localeState, setLocaleState] = useState<Locale>('fa');
  const [localeTitle, setLocaleTitle] = useState('تقویم میلادی');
  const [selectedDate, setSelectedDate] = useState<DayItem | undefined>();
  const [monthsState, setMonthsState] = useState<MonthItem[]>([]);

  const todayGregorian = sdate.format('en', new Date(), '/').YYYY_MM_dd;
  let currentYear = sdate.convert('fa', new Date()).YYYY as any;
  let currentMonth = sdate.convert('fa', new Date()).MM;

  useEffect(() => {
    setMonthsState(
      getMonthDetails('fa', currentYear, currentMonth, numberOfMonth, subTitles, todayGregorian)
    );
  }, [numberOfMonth, subTitles, todayGregorian, currentYear, currentMonth]);

  const toggleCalendarType = () => {
    const newLocale = localeState === 'en' ? 'fa' : 'en';
    setLocaleState(newLocale);
    setLocaleTitle(newLocale === 'en' ? 'تقویم شمسی' : 'تقویم میلادی');
    currentYear = sdate.format(newLocale, new Date()).YYYY;
    currentMonth = sdate.format(newLocale, new Date()).MM;
    setMonthsState(
      getMonthDetails(
        newLocale,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const nextMonth = () => {
    if (+currentMonth + 1 === 13) {
      currentYear++;
      currentMonth = 1;
    } else {
      currentMonth++;
    }
    setMonthsState(
      getMonthDetails(
        localeState,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const prevMonth = () => {
    if (
      isDisabledPast &&
      +currentMonth === +sdate.convert(localeState, new Date()).MM &&
      +currentYear === +sdate.convert(localeState, new Date()).YYYY
    )
      return;

    if (+currentMonth - 1 === 0) {
      currentYear--;
      currentMonth = 12;
    } else {
      currentMonth--;
    }
    setMonthsState(
      getMonthDetails(
        localeState,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const gotoToday = () => {
    setMonthsState(
      getMonthDetails(
        localeState,
        currentYear,
        currentMonth,
        numberOfMonth,
        subTitles,
        todayGregorian
      )
    );
  };

  const handleChange = (date: DayItem) => {
    setSelectedDate(date);
    onChange(date.jalaliDate);
  };

  return (
    <div
      className={`calendar ${numberOfMonth > 1 ? 'active' : ''} ${localeState === 'fa' ? '-rtl' : '-ltr'}`}
    >
      <div className="calendar__navigation fixed-position">
        <button type="button" onClick={gotoToday}>
          برو به امروز
        </button>
        <button type="button" onClick={toggleCalendarType}>
          {localeTitle}
        </button>
      </div>

      <div className="s-relative s-block s-w-full">
        <Header onNextMonth={nextMonth} onPrevMonth={prevMonth} />

        <div className="s-grid s-gap-8 s-p-3 md:s-flex">
          {monthsState.map((monthItem, monthIndex) => (
            <div key={monthIndex} className="s-mt-[2px] s-flex-1">
              <div className="s-mx-1.5 s-grid s-grid-cols-5 s-items-center s-gap-x-3 s-pb-2 s-pt-4">
                <span className="s-col-span-5 s-mb-2 s-text-left s-text-base s-font-semibold s-text-black md:s-text-sm">
                  {`${monthItem.monthName} ${monthItem.year}`}
                </span>

                {['ش', 'ی', 'د', 'س', 'چ', 'پ', 'ج'].map((weekDay, weekIndex) => (
                  <span
                    key={weekIndex}
                    className="s-text-center s-text-sm s-font-semibold s-text-slate-600"
                  >
                    {weekDay}
                  </span>
                ))}

                {monthItem.days.map((dayItem, dayIndex) => (
                  <div key={dayIndex} className="s-relative s-mt-2">
                    <button
                      type="button"
                      onClick={() => handleChange(dayItem)}
                      className={`${
                        selectedDate && selectedDate.value === dayItem.value ? 'selected' : ''
                      } ${dayItem.isPassed ? 's-text-gray-400' : 's-text-gray-700'} s-flex s-h-12 s-w-12 s-items-center s-justify-center s-bg-transparent`}
                      disabled={dayItem.isPassed}
                    >
                      {dayItem.day}
                    </button>
                    {dayItem.subTitle && (
                      <span className="s-absolute s-right-0 s-top-0 s-flex s-h-4 s-w-4 s-items-center s-justify-center s-rounded-full s-bg-red-500 s-text-xs s-text-white">
                        {dayItem.subTitle}
                      </span>
                    )}
                  </div>
                ))}
              </div>
            </div>
          ))}
        </div>

        <div className="s-relative s-mt-8 s-w-full s-pb-4">
          <button type="button" className="s-btn s-btn-primary s-w-full" onClick={submitBtnAction}>
            ثبت تاریخ
          </button>
        </div>
      </div>
    </div>
  );
};

export default DatePicker;
